SigningAlgorithm

Enum SigningAlgorithm 

pub enum SigningAlgorithm {
    Es256,
    Es384,
    Es512,
    Ps256,
    Ps384,
    Ps512,
}
Signature algorithms approved for use in the context of EUDI.

Algorithms

This enumeration contains only JOSE asymmetric signature algorithms approved for use by SOG-IS ACM v1.2, with any parameters (e.g. RSA modulus size) meeting therein imposed requirements.

For more details see the following references:

Variants



Es256

ECDSA over P-256 with SHA-256



Es384

ECDSA over P-384 with SHA-384



Es512

ECDSA over P-521 with SHA-512



Ps256

RSASSA-PSS with SHA-256 and MGF1 with SHA-256



Ps384

RSASSA-PSS with SHA-384 and MGF1 with SHA-384



Ps512

RSASSA-PSS with SHA-512 and MGF1 with SHA-512